@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2020, 2021.
+# (C) Copyright IBM 2020, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -33,6 +33,17 @@ from .excited_states_solver import ExcitedStatesSolver
 from .qeom import QEOM
 from .eigensolver_factories import EigensolverFactory, NumPyEigensolverFactory
 from .excited_states_eigensolver import ExcitedStatesEigensolver
+from ...deprecation import warn_deprecated, DeprecatedType, NatureDeprecationWarning
+
+warn_deprecated(
+    "0.5.0",
+    old_type=DeprecatedType.PACKAGE,
+    old_name="qiskit_nature.algorithms.excited_state_solvers",
+    new_type=DeprecatedType.PACKAGE,
+    new_name="qiskit_nature.second_q.algorithms.excited_state_solvers",
+    stack_level=3,
+    category=NatureDeprecationWarning,
+)
 
 __all__ = [
     "ExcitedStatesSolver",
