@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2020, 2021.
+# (C) Copyright IBM 2020, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -71,6 +71,20 @@ from .potentials import (
     VibrationalStructureBase,
 )
 from .bopes_sampler import BOPESSampler
+from ...deprecation import warn_deprecated, DeprecatedType, NatureDeprecationWarning
+
+warn_deprecated(
+    "0.5.0",
+    old_type=DeprecatedType.PACKAGE,
+    old_name="qiskit_nature.algorithms.pes_sampler",
+    additional_msg=(
+        ". Please refer to "
+        "'https://github.com/Qiskit/qiskit-nature/issues/750'"
+        " for additional information regarding 'extrapolators'"
+    ),
+    stack_level=3,
+    category=NatureDeprecationWarning,
+)
 
 __all__ = [
     "BOPESSampler",
