@@ -17,11 +17,22 @@ from qiskit.opflow import PauliSumOp, PauliOp
 from qiskit.algorithms import MinimumEigensolverResult
 
 from qiskit_nature.results import EigenstateResult
+from ...deprecation import warn_deprecated, DeprecatedType, NatureDeprecationWarning
 
 
 class SamplingProblem(ABC):
     """An interface for sampling problems."""
 
+    def __init__(self):
+        warn_deprecated(
+            "0.5.0",
+            old_type=DeprecatedType.CLASS,
+            old_name="qiskit_nature.problems.sampling.SamplingProblem",
+            additional_msg="This class is being removed from Qiskit Nature",
+            stack_level=3,
+            category=NatureDeprecationWarning,
+        )
+
     @abstractmethod
     def qubit_op(self) -> Union[PauliOp, PauliSumOp]:
         """Returns a qubit operator that represents a Hamiltonian encoding the sampling problem."""
