@@ -19,8 +19,8 @@ import numbers
 
 import numpy as np
 
-from retworkx import NodeIndices, PyGraph, WeightedEdgeList, adjacency_matrix, networkx_converter
-from retworkx.visualization import mpl_draw
+from rustworkx import NodeIndices, PyGraph, WeightedEdgeList, adjacency_matrix, networkx_converter
+from rustworkx.visualization import mpl_draw
 
 from qiskit.utils import optionals as _optionals
 
@@ -38,7 +38,7 @@ if _optionals.HAS_MATPLOTLIB:
 class LatticeDrawStyle:
     """A stylesheet for lattice figure.
     Please see
-    https://qiskit.org/documentation/retworkx/stubs/retworkx.visualization.mpl_draw.html#retworkx.visualization.mpl_draw
+    https://qiskit.org/documentation/rustworkx/stubs/rustworkx.visualization.mpl_draw.html#rustworkx.visualization.mpl_draw
     for each element.
     """
 
@@ -116,8 +116,8 @@ class Lattice:
     def __init__(self, graph: Union[PyGraph, "nx.Graph"]) -> None:
         """
         Args:
-            graph: Input graph for Lattice. Can be provided as ``retworkx.PyGraph``, which is
-                used internally, or, for convenience, as ``networkx.Graph``. The graph
+            graph: Input graph for Lattice. Can be provided as ``rustworkx.PyGraph``, which is
+                used internally, or, for convenience, as ``rustworkx.Graph``. The graph
                 cannot be a multigraph.
 
         Raises:
@@ -247,9 +247,9 @@ class Lattice:
 
         Args:
             self_loop : Draw self-loops in the lattice. Defaults to False.
-            style : Styles for retworkx.visualization.mpl_draw.
+            style : Styles for rustworkx.visualization.mpl_draw.
                 Please see
-                https://qiskit.org/documentation/retworkx/stubs/retworkx.visualization.mpl_draw.html#retworkx.visualization.mpl_draw
+                https://qiskit.org/documentation/rustworkx/stubs/rustworkx.visualization.mpl_draw.html#rustworkx.visualization.mpl_draw
                 for details.
         """
 
