@@ -21,3 +21,15 @@ Transformers (:mod:`qiskit_nature.transformers`)
 
    second_quantization
 """
+
+from ..deprecation import warn_deprecated, DeprecatedType, NatureDeprecationWarning
+
+warn_deprecated(
+    "0.5.0",
+    old_type=DeprecatedType.PACKAGE,
+    old_name="qiskit_nature.transformers",
+    new_type=DeprecatedType.PACKAGE,
+    new_name="qiskit_nature.second_q.transformers",
+    stack_level=3,
+    category=NatureDeprecationWarning,
+)
