@@ -18,11 +18,10 @@ import io
 import unittest
 import warnings
 
-from test import QiskitNatureTestCase
+from test import QiskitNatureDeprecatedTestCase
 
 import numpy as np
 
-import qiskit
 from qiskit import BasicAer
 from qiskit.algorithms import VQE
 from qiskit.algorithms.optimizers import SLSQP, SPSA
@@ -51,7 +50,7 @@ from qiskit_nature import settings
 from qiskit_nature.algorithms.initial_points import MP2InitialPoint
 
 
-class TestGroundStateEigensolver(QiskitNatureTestCase):
+class TestGroundStateEigensolver(QiskitNatureDeprecatedTestCase):
     """Test GroundStateEigensolver"""
 
     def setUp(self):
@@ -330,7 +329,9 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
     def test_eval_op_qasm_aer(self):
         """Regression tests against https://github.com/Qiskit/qiskit-nature/issues/53."""
 
-        backend = qiskit.Aer.get_backend("aer_simulator")
+        from qiskit_aer import Aer
+
+        backend = Aer.get_backend("aer_simulator")
 
         solver = VQEUCCFactory(
             optimizer=SLSQP(maxiter=100),
@@ -415,7 +416,9 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
     def test_uccsd_hf_aer_statevector(self):
         """uccsd hf test with Aer statevector"""
 
-        backend = qiskit.Aer.get_backend("aer_simulator_statevector")
+        from qiskit_aer import Aer
+
+        backend = Aer.get_backend("aer_simulator_statevector")
 
         ansatz = self._prepare_uccsd_hf(self.qubit_converter)
 
@@ -436,7 +439,9 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
     def test_uccsd_hf_aer_qasm(self):
         """uccsd hf test with Aer qasm simulator."""
 
-        backend = qiskit.Aer.get_backend("aer_simulator")
+        from qiskit_aer import Aer
+
+        backend = Aer.get_backend("aer_simulator")
 
         ansatz = self._prepare_uccsd_hf(self.qubit_converter)
 
@@ -462,7 +467,9 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
     def test_uccsd_hf_aer_qasm_snapshot(self):
         """uccsd hf test with Aer qasm simulator snapshot."""
 
-        backend = qiskit.Aer.get_backend("aer_simulator")
+        from qiskit_aer import Aer
+
+        backend = Aer.get_backend("aer_simulator")
 
         ansatz = self._prepare_uccsd_hf(self.qubit_converter)
 
